ExecuteMsg

Enum ExecuteMsg 

pub enum ExecuteMsg {
    Receive(Cw20ReceiveMsg),
    ProvideLiquidity {
        assets: [Asset; 2],
        slippage_tolerance: Option<Decimal>,
        auto_stake: Option<bool>,
        receiver: Option<String>,
    },
    Swap {
        offer_asset: Asset,
        belief_price: Option<Decimal>,
        max_spread: Option<Decimal>,
        to: Option<String>,
    },
    UpdateConfig {
        params: Binary,
    },
    ClaimReward {
        receiver: Option<String>,
    },
    ClaimRewardByGenerator {
        user: String,
        user_share: Uint128,
        total_share: Uint128,
    },
    HandleReward {
        previous_reward_balance: Uint128,
        user: Addr,
        user_share: Uint128,
        total_share: Uint128,
        receiver: Option<Addr>,
    },
}
Description

This structure describes the execute messages available in the contract.

Variants



Receive(Cw20ReceiveMsg)

Description

Receives a message of type Cw20ReceiveMsg



ProvideLiquidity

ProvideLiquidity allows an account to provide liquidity in a pool with bLUNA

Fields

assets: [Asset; 2]

The two assets available in the pool

slippage_tolerance: Option<Decimal>

The slippage tolerance that allows liquidity provision only if the price in the pool doesn’t move too much

auto_stake: Option<bool>

Determines whether the LP tokens minted for the user is auto_staked in the Generator contract

receiver: Option<String>

The receiver of LP tokens



Swap

Swap performs a swap in the pool

Fields

offer_asset: Asset
belief_price: Option<Decimal>
max_spread: Option<Decimal>


UpdateConfig

Update the pair configuration

Fields

params: Binary


ClaimReward

Claims bLUNA rewards and sends them to the specified receiver

Fields

receiver: Option<String>

An address which will receive the bLUNA reward



ClaimRewardByGenerator

Claims the bLUNA reward for a user that deposited their LP tokens in the Generator contract

Fields

user: String

The user whose LP tokens are/were staked in the Generator

user_share: Uint128

The user’s LP token amount before the LP token transfer between their wallet and the Generator

total_share: Uint128

The total LP token amount already deposited by all users in the Generator



HandleReward

Callback for distributing bLUNA rewards

Fields

previous_reward_balance: Uint128
user: Addr
user_share: Uint128
total_share: Uint128
receiver: Option<Addr>